<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" :inline="true" v-show="showSearch">
      <el-form-item label="用户编号" prop="userCode">
        <el-input
          v-model="queryParams.userCode"
          placeholder="请输入用户编号"
          clearable
          size="small"
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="用户名称" prop="userName">
        <el-input
          v-model="queryParams.userName"
          placeholder="请输入用户名称"
          clearable
          size="small"
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="地点" prop="address">
        <el-select v-model="queryParams.address" placeholder="请选择地点" clearable size="small">
          <el-option
            v-for="dict in dict.type.welfare_apply_addr"
            :key="dict.value"
            :label="dict.label"
            :value="dict.value"
          />
        </el-select>
      </el-form-item>
      <el-form-item label="当前状态" prop="nowStatus">
        <el-select v-model="queryParams.nowStatus" placeholder="请选择当前状态" clearable size="small">
          <el-option
            v-for="dict in dict.type.welfare_apply_status"
            :key="dict.value"
            :label="dict.label"
            :value="dict.value"
          />
        </el-select>
      </el-form-item>
      <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
      <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['event:applyRecord:add']"
        >新增
        </el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="success"
          plain
          icon="el-icon-edit"
          size="mini"
          :disabled="single"
          @click="handleUpdate"
          v-hasPermi="['event:applyRecord:edit']"
        >修改
        </el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
          v-hasPermi="['event:applyRecord:remove']"
        >删除
        </el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="warning"
          plain
          icon="el-icon-download"
          size="mini"
          :loading="exportLoading"
          @click="handleExport"
          v-hasPermi="['event:applyRecord:export']"
        >导出
        </el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleImport"
        >导入
        </el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-row :gutter="6">
      <el-col :span="7">
        <el-card class="box-card">
          <div slot="header" class="clearfix">
            <span>福利领取目录</span>
          </div>
          <div class="item">
            <el-table v-loading="loading" :data="sourceList" @selection-change="handleSelectionChange"
                      @row-click="rowClick">
              <el-table-column label="文件名" align="center" prop="source"/>
              <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
                <template slot-scope="scope">
                  <el-button
                    size="mini"
                    type="text"
                    icon="el-icon-pie-chart"
                    @click="openStat(scope.row.source)"
                  >统计
                  </el-button>
                  <el-button
                    size="mini"
                    type="text"
                    icon="el-icon-magic-stick"
                    @click="sourceDoUnregistered(scope.row.source)"
                  >发布
                  </el-button>
                  <el-button
                    size="mini"
                    type="text"
                    icon="el-icon-delete"
                    @click="doDelSource(scope.row.source)"
                  >删除
                  </el-button>
                </template>
              </el-table-column>
            </el-table>
            <pagination
              v-show="total>0"
              :total="sourceQueryParams.total"
              :page.sync="sourceQueryParams.pageNum"
              :limit.sync="sourceQueryParams.pageSize"
              @pagination="getList"
            />
          </div>
        </el-card>
      </el-col>
      <el-col :span="17">
        <el-card class="box-card">
          <div slot="header" class="clearfix">
            <span>{{ sourceName }}</span>
          </div>
          <div class="item">
            <el-table v-loading="loading" :data="applyRecordList" @selection-change="handleSelectionChange">
              <el-table-column type="selection" width="55" align="center"/>
              <el-table-column label="用户编号" align="center" prop="userCode"/>
              <el-table-column label="用户名称" align="center" prop="userName"/>
              <el-table-column label="地点" align="center" prop="address" width="380">
                <template slot-scope="scope">
                  <dict-tag :options="dict.type.welfare_apply_addr" :value="scope.row.address"/>
                </template>
              </el-table-column>
              <el-table-column label="当前状态" align="center" prop="nowStatus">
                <template slot-scope="scope">
                  <dict-tag :options="dict.type.welfare_apply_status" :value="scope.row.nowStatus"/>
                </template>
              </el-table-column>
              <el-table-column label="备注" align="center" prop="remark"/>
              <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
                <template slot-scope="scope">
                  <el-button
                    size="mini"
                    type="text"
                    icon="el-icon-edit"
                    @click="handleUpdate(scope.row)"
                  >修改
                  </el-button>
                  <el-button
                    size="mini"
                    type="text"
                    icon="el-icon-delete"
                    @click="handleDelete(scope.row)"
                  >删除
                  </el-button>
                </template>
              </el-table-column>
            </el-table>
            <pagination
              v-show="total>0"
              :total="total"
              :page.sync="queryParams.pageNum"
              :limit.sync="queryParams.pageSize"
              @pagination="getList"
            />
          </div>
        </el-card>
      </el-col>
    </el-row>
    <!-- 添加或修改福利报名记录对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="600px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules">
        <el-form-item label="Excel来源" prop="source">
          <el-input v-model="form.source" placeholder="请输入Excel来源"/>
        </el-form-item>
        <el-form-item label="用户编号" prop="userCode">
          <el-input v-model="form.userCode" placeholder="请输入用户编号"/>
        </el-form-item>
        <el-form-item label="用户名称" prop="userName">
          <el-input v-model="form.userName" placeholder="请输入用户名称"/>
        </el-form-item>
        <el-form-item label="地点" prop="address">
          <el-select v-model="form.address" placeholder="请选择地点">
            <el-option
              v-for="dict in dict.type.welfare_apply_addr"
              :key="dict.value"
              :label="dict.label"
              :value="dict.value"
            ></el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="当前状态" prop="nowStatus">
          <el-select v-model="form.nowStatus" placeholder="请选择当前状态">
            <el-option
              v-for="dict in dict.type.welfare_apply_status"
              :key="dict.value"
              :label="dict.label"
              :value="dict.value"
            ></el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="备注" prop="remark">
          <el-input v-model="form.remark" placeholder="请输入备注"/>
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>

    <el-dialog :title="upload.title" :visible.sync="upload.open" width="400px" append-to-body>
      <el-upload
        ref="upload"
        :limit="1"
        accept=".xlsx, .xls"
        :headers="upload.headers"
        :action="upload.url"
        :disabled="upload.isUploading"
        :on-progress="handleFileUploadProgress"
        :on-success="handleFileSuccess"
        :auto-upload="false"
        drag
      >
        <i class="el-icon-upload"></i>
        <div class="el-upload__text">将文件拖到此处，或<em>点击上传</em></div>
        <div class="el-upload__tip text-center" slot="tip">
          <span>仅允许导入xls、xlsx格式文件。</span>
          <el-link type="primary" :underline="false" style="font-size:12px;vertical-align: baseline;"
                   @click="importTemplate">下载模板
          </el-link>
        </div>
      </el-upload>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitFileForm">确 定</el-button>
        <el-button @click="cancelTemplate">取 消</el-button>
      </div>
    </el-dialog>
    <el-dialog :title="stat.title" :visible.sync="stat.open" width="900px">
      <el-table v-loading="stat.loading" :data="statList" :show-summary="true">
        <el-table-column label="部门" align="center" prop="address"/>
        <el-table-column label="报名数量" align="center" prop="applyNum"/>
      </el-table>
    </el-dialog>
  </div>
</template>

<script>
import {
  listApplyRecord,
  sourceListApplyRecord,
  statApplyRecord,
  doUnregistered,
  getApplyRecord,
  delApplyRecord,
  delSource,
  addApplyRecord,
  updateApplyRecord,
  exportApplyRecord,
  importTempApplyRecord
} from '@/api/event/applyRecord'
import { getToken } from '@/utils/auth'
import { exportDetail } from '@/api/canteen/giftDetail'

export default {
  name: 'ApplyRecord',
  dicts: ['welfare_apply_status', 'welfare_apply_addr'],
  data() {
    return {
      // 遮罩层
      loading: true,
      // 导出遮罩层
      exportLoading: false,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 福利报名记录表格数据
      applyRecordList: [],
      sourceList: [],
      statList: [],
      // 弹出层标题
      title: '',
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        source: null,
        userCode: null,
        userName: null,
        address: null,
        nowStatus: null,
        isDelete: null
      },
      sourceQueryParams: {
        pageNum: 1,
        pageSize: 10,
        total: 0
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {},
      sourceName: '',
      upload: {
        // 是否显示弹出层（用户导入）
        open: false,
        // 弹出层标题（用户导入）
        title: '',
        // 是否禁用上传
        isUploading: false,
        // 是否更新已经存在的用户数据
        // 设置上传的请求头部
        headers: { Authorization: 'Bearer ' + getToken() },
        // 上传的地址
        url: process.env.VUE_APP_BASE_API + '/event/applyRecord/importData'
      },
      stat: {
        open: false,
        title: '统计',
        loading: false
      }
    }
  },
  created() {
    this.getList()
  },
  methods: {
    rowClick(row) {
      this.loading = true
      this.queryParams.source = row.source
      this.sourceName = row.source
      listApplyRecord(this.queryParams).then(response => {
        this.applyRecordList = response.rows
        this.total = response.total
        this.loading = false
      })
    },
    /** 查询福利报名记录列表 */
    getList() {
      this.loading = true
      listApplyRecord(this.queryParams).then(response => {
        this.applyRecordList = response.rows
        this.total = response.total
        this.loading = false
      })
      sourceListApplyRecord(this.sourceQueryParams).then(response => {
        this.sourceList = response.rows
        this.sourceQueryParams.total = response.total
      })
    },
    openStat(source) {
      this.stat.open = true
      this.stat.loading = true
      this.stat.title = '统计【' + source + '】'
      statApplyRecord(source).then(response => {
        if (response.code === 200) {
          this.statList = response.data
          this.stat.loading = false
        }
      })
    },
    sourceDoUnregistered(source) {
      this.$modal.confirm('发布成功后所有人员都设置为【未报名】状态，确认发布吗？').then(() => {
        return doUnregistered(source)
      }).then(response => {
        if (response.code === 200) {
          this.$modal.msgSuccess('发布成功')
          this.getList()
        } else {
          this.$modal.msgError('发布失败')
        }
      }).catch(() => {

      })
    },
    doDelSource(source) {
      this.$modal.confirm('删除后所有信息都将删除，确认删除吗？').then(() => {
        return delSource(source)
      }).then(response => {
        if (response.code === 200) {
          this.$modal.msgSuccess('删除成功')
          this.getList()
        } else {
          this.$modal.msgError('删除失败')
        }
      })
    },
    // 取消按钮
    cancel() {
      this.open = false
      this.reset()
    },
    // 表单重置
    reset() {
      this.form = {
        id: null,
        source: null,
        userCode: null,
        userName: null,
        address: null,
        nowStatus: '0',
        isDelete: null,
        createBy: null,
        createTime: null,
        updateBy: null,
        updateTime: null,
        remark: null
      }
      this.resetForm('form')
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1
      this.getList()
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm('queryForm')
      this.handleQuery()
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.id)
      this.single = selection.length !== 1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset()
      this.open = true
      this.title = '添加福利报名记录'
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset()
      const id = row.id || this.ids
      getApplyRecord(id).then(response => {
        this.form = response.data
        this.open = true
        this.title = '修改福利报名记录'
      })
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs['form'].validate(valid => {
        if (valid) {
          if (this.form.id != null) {
            updateApplyRecord(this.form).then(() => {
              this.$modal.msgSuccess('修改成功')
              this.open = false
              this.getList()
            })
          } else {
            addApplyRecord(this.form).then(() => {
              this.$modal.msgSuccess('新增成功')
              this.open = false
              this.getList()
            })
          }
        }
      })
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids
      this.$modal.confirm('是否确认删除福利报名记录编号为"' + ids + '"的数据项？').then(function() {
        return delApplyRecord(ids)
      }).then(() => {
        this.getList()
        this.$modal.msgSuccess('删除成功')
      }).catch(() => {
      })
    },
    /** 导出按钮操作 */
    handleExport() {
      const queryParams = this.queryParams
      this.$modal.confirm('是否确认导出所有福利报名记录数据项？').then(() => {
        this.exportLoading = true
        return exportApplyRecord(queryParams)
      }).then(response => {
        this.$download.name(response.msg)
        this.exportLoading = false
      }).catch(() => {
      })
    },
    handleImport() {
      this.upload.title = '福利领取人员导入'
      this.upload.open = true
    },
    handleFileUploadProgress(event, file, fileList) {
      this.upload.isUploading = true
    },
    // 文件上传成功处理
    handleFileSuccess(response, file, fileList) {
      this.upload.open = false
      this.upload.isUploading = false
      this.$refs.upload.clearFiles()
      this.$alert(response.msg, '导入结果', { dangerouslyUseHTMLString: true })
      this.cancel()
      this.getList()
    },
    importTemplate() {
      importTempApplyRecord().then(response => {
        this.$download.name(response.msg)
      })
    },
    submitFileForm() {
      this.$refs.upload.submit()
    },
    cancelTemplate() {
      this.upload.open = false
    }
  }
}

</script>
